@@ -11,7 +11,7 @@ use Carp;
 use JSON::XS;
 use URI;    # The GET requests need URI-escaping
 
-our $VERSION = '0.02_02';
+our $VERSION = '0.02_03';
 
 sub new {
 	my ($class, %opts) = @_;
@@ -26,6 +26,7 @@ sub new {
 		ua => REST::Client->new (
 			{   host    => 'https://api.abuseipdb.com',
 				timeout => $opts{timeout} // 20,
+				agent   => "WebService::AbuseIPDB/$VERSION",
 
 #			useragent => LWP::UserAgent->new (ssl_opts => {
 #					verify_hostname => 1,
@@ -51,7 +52,7 @@ sub _send_receive {
 		Accept => 'application/json',
 		Key    => $self->{key}
 	};
-	if ($meth eq 'GET' && $data) {
+	if ($meth eq 'GET') {
 		my $u = URI->new ($path);
 		$u->query_form (%$data);
 		$path = $u->as_string;
@@ -79,7 +80,7 @@ sub _send_receive {
 	}
 
 	carp "Problem with $meth $path";
-	carp "Data was " . encode_json ($data) if defined $data;
+	carp "Data was " . encode_json ($data);
 	carp "Client warning: ", $self->{ua}->responseHeader ('Client-Warning');
 	return undef;
 }
